==> libreoffice-7.3.1.1.tar.xz: libreoffice-7.3.1.1/comphelper/source/misc/accimplaccess.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <comphelper/accimplaccess.hxx>
#include <comphelper/servicehelper.hxx>

#include <string.h>


namespace comphelper
{


    using ::com::sun::star::uno::Sequence;

    OAccessibleImplementationAccess::OAccessibleImplementationAccess( )
    {
    }


    OAccessibleImplementationAccess::~OAccessibleImplementationAccess( )
    {
    }

    Sequence<sal_Int8> OAccessibleImplementationAccess::getUnoTunnelId()
    {
        static const comphelper::UnoIdInit implID;
        return implID.getSeq();
    }


    sal_Int64 SAL_CALL OAccessibleImplementationAccess::getSomething( const Sequence< sal_Int8 >& _rIdentifier )
    {
        return comphelper::getSomethingImpl(_rIdentifier, this);
    }

}   // namespace comphelper


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_7.4.7.orig.tar.xz: libreoffice-7.4.7.2/comphelper/source/misc/accimplaccess.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <comphelper/accimplaccess.hxx>
#include <comphelper/servicehelper.hxx>


namespace comphelper
{


    using ::com::sun::star::uno::Sequence;

    OAccessibleImplementationAccess::OAccessibleImplementationAccess( )
    {
    }


    OAccessibleImplementationAccess::~OAccessibleImplementationAccess( )
    {
    }

    const Sequence<sal_Int8> & OAccessibleImplementationAccess::getUnoTunnelId()
    {
        static const comphelper::UnoIdInit implID;
        return implID.getSeq();
    }


    sal_Int64 SAL_CALL OAccessibleImplementationAccess::getSomething( const Sequence< sal_Int8 >& _rIdentifier )
    {
        return comphelper::getSomethingImpl(_rIdentifier, this);
    }

}   // namespace comphelper


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
